"""A suite of common debug routines."""

from .sparse_memory import SparseMemory
from .debug_manager import DebugManager

__all__ = ['SparseMemory', 'DebugManager']
